@@ -4,11 +4,8 @@ use feature 'switch';
 use utf8;
 
 package Dist::Zilla::PluginBundle::Author::RTHOMPSON;
-{
-  $Dist::Zilla::PluginBundle::Author::RTHOMPSON::VERSION = '0.133030';
-}
 # ABSTRACT: RTHOMPSON's Dist::Zilla Configuration
-
+$Dist::Zilla::PluginBundle::Author::RTHOMPSON::VERSION = '0.142180';
 use Moose;
 use Carp;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -41,8 +38,6 @@ sub configure {
         # Archive releases
         archive => 1,
         archive_directory => 'releases',
-        # Copy README.pod from build dir to dist dir, for Github and
-        # suchlike.
         copy_file => [],
         move_file => [],
         # version control system = git
@@ -74,7 +69,7 @@ sub configure {
         );
     }
 
-    # Copy files from build dir
+    # Copy/move files from build dir
     if ($args{copy_file} or $args{move_file}) {
         $self->add_plugins(
             [ 'CopyFilesFromBuild' => {
@@ -141,7 +136,9 @@ sub configure {
         ['ReadmeAnyFromPod', 'ReadmeTextInBuild'],
         # This one gets copied out of the build dir by default, and
         # does not become part of the dist.
-        ['ReadmeAnyFromPod', 'ReadmePodInRoot '],
+        ['ReadmeAnyFromPod', 'ReadmePodInRoot ' => {
+            phase => 'release',
+        }],
 
         # Tests
         'Test::Perl::Critic',
@@ -236,7 +233,7 @@ Dist::Zilla::PluginBundle::Author::RTHOMPSON - RTHOMPSON's Dist::Zilla Configura
 
 =head1 VERSION
 
-version 0.133030
+version 0.142180
 
 =head1 SYNOPSIS
 
@@ -356,10 +353,7 @@ If you want to include an auto-generated file in your distribution but
 you I<don't> want to include it in the build, use C<move_file> instead
 of C<copy_file>.
 
-The default is to move F<README.pod> out of the build dir. If you use
-C<move_file> in your configuration, this default will be disabled, so
-if you want it, make sure to include it along with your other
-C<move_file>s.
+By default, both of these options are unset.
 
 Example:
 
